<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2004 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: init.php 2024 2005-03-10 17:21:43Z andrew $
*/

/**
 * @package    Max
 * @author     Andrew Hill <andrew@awarez.net>
 *
 * A file to set up the environment for the Max administration interface.
 */

require_once 'constants.php';
require_once 'PEAR.php';

/**
 * The environment initialisation function for the Max administration interface.
 *
 * @TODO Should move the user authentication, loading of preferences into this
 *       file, and out of the /www/admin/config.php file.
 */
function init()
{
    // Disable all notices and warnings, as some PAN code still
    // generates PHP warnings in places
    error_reporting(E_ALL ^ E_NOTICE ^ E_WARNING);
    // If not being called from the installation script...
    if (basename($_SERVER['PHP_SELF']) != 'install.php') {
        // Direct the user to the installation script if not installed
        if (!$GLOBALS['_MAX']['CONF']['max']['installed']) {
            if ($GLOBALS['_MAX']['ROOT_INDEX']) {
                // The root /index.php page was called to get here, so
                // the user has pointed the root of the web directory
                // to the Max installation root
                $location = 'Location: ' . $GLOBALS['_MAX']['HTTP'] . 
                       $_SERVER['HTTP_HOST'] . '/www/admin/' . 'install.php';
                header($location);
            } elseif ($GLOBALS['_MAX']['WWW_INDEX']) {
                // The www/index.php page was called to get here, so
                // the user has pointed the root of the web directory
                // to the Max /www directory
                $location = 'Location: ' . $GLOBALS['_MAX']['HTTP'] . 
                       $_SERVER['HTTP_HOST'] . '/admin/' . 'install.php';
                header($location);
            } else {
                // The user has pointed a virtual host to the 
                // /www/admin directory
                $location = 'Location: ' . $GLOBALS['_MAX']['HTTP'] . 
                       $_SERVER['HTTP_HOST'] . '/install.php';
                header($location);
            }
            exit();
        }
    }
    // Load backwards compatibility for old PHP, if required
    if (!function_exists('version_compare') || version_compare(phpversion(), "4.3.0", 'lt')) {
        include_once MAX_PATH . '/etc/bc.php';
    }  
}

// Run the init() function
init();

// Set $conf
$conf = $GLOBALS['_MAX']['CONF'];

?>
