<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfDalStatisticsAdServerMySql.php 2024 2005-03-10 17:21:43Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once MAX_PATH . '/lib/Max.php';
require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Dal/Statistics/AdServer/MySql.php';
 
/**
 * A class for testing the MAX_Dal_Statistics_AdServer_MySql class.
 */
class Dal_TestOfMaxDalStatisticsAdServerMySql extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Dal_TestOfMaxDalStatisticsAdServerMySql()
    {
        $this->UnitTestCase();
    }
    
    /**
     * Tests the getMaintenanceStatisticsLastRunInfo() method.
     */
    function testGetMaintenanceStatisticsLastRunInfo()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $backup = $conf['table']['prefix'];
        $dbh =& MAX_DB::singleton();
        $conf['maintenance']['operationInterval'] = 60;
        $conf['table']['split'] = false;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('data_raw_ad_impression');
        $dsa->tables->createTable('log_maintenance_statistics');
        // Test with no data
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertNull($date);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertNull($date);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert ad impressions
        $result = $dbh->query(DATA_RAW_AD_IMPRESSIONS);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, new Date('2004-05-06 11:59:59'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, new Date('2004-05-06 11:59:59'));
        // Insert an hourly (only) update
        $result = $dbh->query(LMS_HOUR);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, new Date('2004-05-06 11:59:59'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert an operation interval (only) update
        $result = $dbh->query(LMS_OI);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, new Date('2004-06-06 10:16:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert a dual interval update
        $result = $dbh->query(LMS_DUAL);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['log_maintenance_statistics']);
    }
    
    /**
     * Tests the summariseRequests() method.
     */
    function testSummariseRequests()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $conf['table']['split'] = false;
        $conf['maintenance']['operationInterval'] = 30;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('data_raw_ad_request');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert 3 ad requests
        $result = $dbh->query(SUMMARISE_AD_REQUESTS);
        // Summarise where requests don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Summarise where one requests exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        // Summarise where the other two requests exists
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseRequests($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request
            WHERE
                day = '2004-05-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_request
            WHERE
                day = '2004-06-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                requests AS requests
            FROM
                tmp_ad_request
            WHERE
                day = '2004-06-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['requests'], 2);          
        // Drop the tables
        $dsa->tempTables->dropTempTable('tmp_ad_request');
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_request']);
    }
    
    /**
     * Tests the summariseImpressions() method.
     */
    function testSummariseImpressions()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $conf['maintenance']['operationInterval'] = 30;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('data_raw_ad_impression');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert 3 ad impressions
        $result = $dbh->query(SUMMARISE_AD_IMPRESSIONS);
        // Summarise where impressions don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Summarise where one impression exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        // Summarise where the other two impression exists
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseImpressions($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression
            WHERE
                day = '2004-05-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_impression
            WHERE
                day = '2004-06-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                impressions AS impressions
            FROM
                tmp_ad_impression
            WHERE
                day = '2004-06-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['impressions'], 2);          
        // Drop the tables
        $dsa->tempTables->dropTempTable('tmp_ad_impression');
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
    }
    
    /**
     * Tests the summariseClicks() method.
     */
    function testSummariseClicks()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $conf['maintenance']['operationInterval'] = 30;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('data_raw_ad_click');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert 3 ad clicks
        $result = $dbh->query(SUMMARISE_AD_CLICKS);
        // Summarise where clicks don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Summarise where one click exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        // Summarise where the other two clicks exists
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseClicks($start, $end);
        $this->assertEqual($rows, 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click
            WHERE
                day = '2004-05-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_click
            WHERE
                day = '2004-06-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                clicks AS clicks
            FROM
                tmp_ad_click
            WHERE
                day = '2004-06-06'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['clicks'], 2);          
        // Drop the tables
        $dsa->tempTables->dropTempTable('tmp_ad_click');
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_click']);
    }
    
    /**
     * Tests the summariseConnections() method.
     */
    function testSummariseConnections()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $conf['maintenance']['operationInterval'] = 30;
        $conf['modules']['Tracker'] = true;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('banners');
        $dsa->tables->createTable('campaigns_trackers');
        $dsa->tables->createTable('data_raw_ad_click');
        $dsa->tables->createTable('data_raw_ad_impression');
        $dsa->tables->createTable('data_raw_tracker_impression');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert some ads (banners), campaign trackers, ad
        // impressions, ad clicks, and tracker impressions
        $result = $dbh->query(SUMMARISE_CONVERSIONS_BANNERS);
        $result = $dbh->query(SUMMARISE_CONVERSIONS_CAMPAIGNS_TRACKERS);
        $result = $dbh->query(SUMMARISE_CONVERSIONS_AD_IMPRESSIONS);
        $result = $dbh->query(SUMMARISE_CONVERSIONS_AD_CLICKS);
        $result = $dbh->query(SUMMARISE_CONVERSIONS_TRACKER_IMPRESSIONS);
        // Summarise where tracker impressions don't exist
        $start = new Date('2004-05-06 12:00:00');
        $end = new Date('2004-05-06 12:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Summarise where just one tracker impression exists
        $start = new Date('2004-05-06 12:30:00');
        $end = new Date('2004-05-06 12:59:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 2);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 0";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 2);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-05-06 12:34:56');
        $this->assertEqual($row['connection_ad_id'], 2);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan2');
        $this->assertEqual($row['connection_language'], 'en2');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.2');
        $this->assertEqual($row['connection_host_name'], 'localhost2');
        $this->assertEqual($row['connection_country'], 'U2');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain2');
        $this->assertEqual($row['connection_page'], 'page2');
        $this->assertEqual($row['connection_query'], 'query2');
        $this->assertEqual($row['connection_referer'], 'referer2');
        $this->assertEqual($row['connection_search_term'], 'term2');
        $this->assertEqual($row['connection_user_agent'], 'agent2');
        $this->assertEqual($row['connection_os'], 'linux2');
        $this->assertEqual($row['connection_browser'], 'mozilla2');
        $this->assertEqual($row['connection_type'], 0);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 0);
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 2);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-05-06 12:34:56');
        $this->assertEqual($row['connection_ad_id'], 2);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan2');
        $this->assertEqual($row['connection_language'], 'en2');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.2');
        $this->assertEqual($row['connection_host_name'], 'localhost2');
        $this->assertEqual($row['connection_country'], 'U2');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain2');
        $this->assertEqual($row['connection_page'], 'page2');
        $this->assertEqual($row['connection_query'], 'query2');
        $this->assertEqual($row['connection_referer'], 'referer2');
        $this->assertEqual($row['connection_search_term'], 'term2');
        $this->assertEqual($row['connection_user_agent'], 'agent2');
        $this->assertEqual($row['connection_os'], 'linux2');
        $this->assertEqual($row['connection_browser'], 'mozilla2');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 0);
        $this->assertEqual($row['latest'], 0);
        // Drop the temporary table
        $dsa->tempTables->dropTempTable('tmp_ad_connection');
        // Summarise where the other connections are        
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 4);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 4);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 1
                AND connection_ad_id = 3";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:11');
        $this->assertEqual($row['connection_ad_id'], 3);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan3');
        $this->assertEqual($row['connection_language'], 'en3');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.3');
        $this->assertEqual($row['connection_host_name'], 'localhost3');
        $this->assertEqual($row['connection_country'], 'U3');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain3');
        $this->assertEqual($row['connection_page'], 'page3');
        $this->assertEqual($row['connection_query'], 'query3');
        $this->assertEqual($row['connection_referer'], 'referer3');
        $this->assertEqual($row['connection_search_term'], 'term3');
        $this->assertEqual($row['connection_user_agent'], 'agent3');
        $this->assertEqual($row['connection_os'], 'linux3');
        $this->assertEqual($row['connection_browser'], 'mozilla3');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 1
                AND connection_ad_id = 4";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:12');
        $this->assertEqual($row['connection_ad_id'], 4);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan4');
        $this->assertEqual($row['connection_language'], 'en4');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.4');
        $this->assertEqual($row['connection_host_name'], 'localhost4');
        $this->assertEqual($row['connection_country'], 'U4');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain4');
        $this->assertEqual($row['connection_page'], 'page4');
        $this->assertEqual($row['connection_query'], 'query4');
        $this->assertEqual($row['connection_referer'], 'referer4');
        $this->assertEqual($row['connection_search_term'], 'term4');
        $this->assertEqual($row['connection_user_agent'], 'agent4');
        $this->assertEqual($row['connection_os'], 'linux4');
        $this->assertEqual($row['connection_browser'], 'mozilla4');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                tmp_ad_connection";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 4);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 0
                AND connection_ad_id = 3";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:11');
        $this->assertEqual($row['connection_ad_id'], 3);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan3');
        $this->assertEqual($row['connection_language'], 'en3');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.3');
        $this->assertEqual($row['connection_host_name'], 'localhost3');
        $this->assertEqual($row['connection_country'], 'U3');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain3');
        $this->assertEqual($row['connection_page'], 'page3');
        $this->assertEqual($row['connection_query'], 'query3');
        $this->assertEqual($row['connection_referer'], 'referer3');
        $this->assertEqual($row['connection_search_term'], 'term3');
        $this->assertEqual($row['connection_user_agent'], 'agent3');
        $this->assertEqual($row['connection_os'], 'linux3');
        $this->assertEqual($row['connection_browser'], 'mozilla3');
        $this->assertEqual($row['connection_type'], 0);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                *
            FROM
                tmp_ad_connection
            WHERE
                connection_type = 0
                AND connection_ad_id = 4";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['connection_viewer_id'], 'aa');
        $this->assertEqual($row['connection_viewer_session_id'], 0);
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:22:12');
        $this->assertEqual($row['connection_ad_id'], 4);
        $this->assertEqual($row['connection_creative_id'], 0);
        $this->assertEqual($row['connection_zone_id'], 0);
        $this->assertEqual($row['connection_channel'], 'chan4');
        $this->assertEqual($row['connection_language'], 'en4');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.4');
        $this->assertEqual($row['connection_host_name'], 'localhost4');
        $this->assertEqual($row['connection_country'], 'U4');
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['connection_domain'], 'domain4');
        $this->assertEqual($row['connection_page'], 'page4');
        $this->assertEqual($row['connection_query'], 'query4');
        $this->assertEqual($row['connection_referer'], 'referer4');
        $this->assertEqual($row['connection_search_term'], 'term4');
        $this->assertEqual($row['connection_user_agent'], 'agent4');
        $this->assertEqual($row['connection_os'], 'linux4');
        $this->assertEqual($row['connection_browser'], 'mozilla4');
        $this->assertEqual($row['connection_type'], 0);
        $this->assertEqual($row['connection_window'], 2592000);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        // Drop the temporary table
        $dsa->tempTables->dropTempTable('tmp_ad_connection');  
        // Test with the data present, but the tracker module uninstalled
        $conf['modules']['Tracker'] = false;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Summarise where the other connections are        
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $rows = $dsa->summariseConnections($start, $end);
        $this->assertEqual($rows, 0);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['banners']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['campaigns_trackers']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_click']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_impression']);
    }
    
    /**
     * Tests the saveIntermediate() method.
     */
    function testSaveIntermediate()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $conf['maintenance']['operationInterval'] = 30;
        $conf['modules']['Tracker'] = true;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_connection');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        $dsa->tables->createTable('data_intermediate_ad');
        $dsa->tables->createTable('data_intermediate_ad_connection');
        $dsa->tables->createTable('data_intermediate_ad_variable_value');
        $dsa->tables->createTable('data_raw_tracker_impression');
        $dsa->tables->createTable('data_raw_tracker_variable_value');
        $dsa->tables->createTable('variables');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Re-create dropped tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_connection');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert the test data
        $result = $dbh->query(SAVE_INTERMEDIATE_VARIABLES);
        $result = $dbh->query(SAVE_INTERMEDIATE_AD_CLICKS);
        $result = $dbh->query(SAVE_INTERMEDIATE_AD_IMPRESSIONS);
        $result = $dbh->query(SAVE_INTERMEDIATE_AD_REQUESTS);
        $result = $dbh->query(SAVE_INTERMEDIATE_TRACKER_IMPRESSIONS);
        $result = $dbh->query(SAVE_INTERMEDIATE_TRACKER_VARIABLE_VALUES);
        $result = $dbh->query(SAVE_INTERMEDIATE_CONNECTIONS);
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']}
            WHERE
                server_raw_tracker_impression_id = 1
                AND server_raw_ip = '127.0.0.1'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 1);
        $this->assertEqual($row['server_raw_ip'], '127.0.0.1');
        $this->assertEqual($row['viewer_id'], 'aa');
        $this->assertEqual($row['viewer_session_id'], 1);
        $this->assertEqual($row['tracker_date_time'], '2004-06-06 18:10:15');
        $this->assertEqual($row['connection_date_time'], '2004-06-06 18:00:00');
        $this->assertEqual($row['tracker_id'], 1);
        $this->assertEqual($row['ad_id'], 1);
        $this->assertEqual($row['creative_id'], 1);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['tracker_channel'], 'tchan1');
        $this->assertEqual($row['connection_channel'], 'chan1');
        $this->assertEqual($row['tracker_language'], 'ten1');
        $this->assertEqual($row['connection_language'], 'en1');
        $this->assertEqual($row['tracker_ip_address'], 't127.0.0.1');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.1');
        $this->assertEqual($row['tracker_host_name'], 'thost1');
        $this->assertEqual($row['connection_host_name'], 'host1');
        $this->assertEqual($row['tracker_country'], 'T1');
        $this->assertEqual($row['connection_country'], 'U1');
        $this->assertEqual($row['tracker_https'], 1);
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['tracker_domain'], 'tdomain1');
        $this->assertEqual($row['connection_domain'], 'domain1');
        $this->assertEqual($row['tracker_page'], 'tpage1');
        $this->assertEqual($row['connection_page'], 'page1');
        $this->assertEqual($row['tracker_query'], 'tquery1');
        $this->assertEqual($row['connection_query'], 'query1');
        $this->assertEqual($row['tracker_referer'], 'tref1');
        $this->assertEqual($row['connection_referer'], 'ref1');
        $this->assertEqual($row['tracker_search_term'], 'tterm1');
        $this->assertEqual($row['connection_search_term'], 'term1');
        $this->assertEqual($row['tracker_user_agent'], 'tagent1');
        $this->assertEqual($row['connection_user_agent'], 'agent1');
        $this->assertEqual($row['tracker_os'], 'tlinux1');
        $this->assertEqual($row['connection_os'], 'linux1');
        $this->assertEqual($row['tracker_browser'], 'tmozilla1');
        $this->assertEqual($row['connection_browser'], 'mozilla1');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 259200);
        $this->assertEqual($row['conversion'], 'n');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']}
            WHERE
                server_raw_tracker_impression_id = 2
                AND server_raw_ip = '127.0.0.2'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 2);
        $this->assertEqual($row['server_raw_ip'], '127.0.0.2');
        $this->assertEqual($row['viewer_id'], 'bb');
        $this->assertEqual($row['viewer_session_id'], 2);
        $this->assertEqual($row['tracker_date_time'], '2004-06-06 18:22:10');
        $this->assertEqual($row['connection_date_time'], '2004-06-05 10:00:00');
        $this->assertEqual($row['tracker_id'], 2);
        $this->assertEqual($row['ad_id'], 2);
        $this->assertEqual($row['creative_id'], 2);
        $this->assertEqual($row['zone_id'], 2);
        $this->assertEqual($row['tracker_channel'], 'tchan2');
        $this->assertEqual($row['connection_channel'], 'chan2');
        $this->assertEqual($row['tracker_language'], 'ten2');
        $this->assertEqual($row['connection_language'], 'en2');
        $this->assertEqual($row['tracker_ip_address'], 't127.0.0.2');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.2');
        $this->assertEqual($row['tracker_host_name'], 'thost2');
        $this->assertEqual($row['connection_host_name'], 'host2');
        $this->assertEqual($row['tracker_country'], 'T2');
        $this->assertEqual($row['connection_country'], 'U2');
        $this->assertEqual($row['tracker_https'], 1);
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['tracker_domain'], 'tdomain2');
        $this->assertEqual($row['connection_domain'], 'domain2');
        $this->assertEqual($row['tracker_page'], 'tpage2');
        $this->assertEqual($row['connection_page'], 'page2');
        $this->assertEqual($row['tracker_query'], 'tquery2');
        $this->assertEqual($row['connection_query'], 'query2');
        $this->assertEqual($row['tracker_referer'], 'tref2');
        $this->assertEqual($row['connection_referer'], 'ref2');
        $this->assertEqual($row['tracker_search_term'], 'tterm2');
        $this->assertEqual($row['connection_search_term'], 'term2');
        $this->assertEqual($row['tracker_user_agent'], 'tagent2');
        $this->assertEqual($row['connection_user_agent'], 'agent2');
        $this->assertEqual($row['tracker_os'], 'tlinux2');
        $this->assertEqual($row['connection_os'], 'linux2');
        $this->assertEqual($row['tracker_browser'], 'tmozilla2');
        $this->assertEqual($row['connection_browser'], 'mozilla2');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 4320);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']}
            WHERE
                server_raw_tracker_impression_id = 3
                AND server_raw_ip = '127.0.0.3'";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['server_raw_tracker_impression_id'], 3);
        $this->assertEqual($row['server_raw_ip'], '127.0.0.3');
        $this->assertEqual($row['viewer_id'], 'cc');
        $this->assertEqual($row['viewer_session_id'], 3);
        $this->assertEqual($row['tracker_date_time'], '2004-06-06 18:22:10');
        $this->assertEqual($row['connection_date_time'], '2004-06-05 10:00:00');
        $this->assertEqual($row['tracker_id'], 3);
        $this->assertEqual($row['ad_id'], 3);
        $this->assertEqual($row['creative_id'], 3);
        $this->assertEqual($row['zone_id'], 3);
        $this->assertEqual($row['tracker_channel'], 'tchan3');
        $this->assertEqual($row['connection_channel'], 'chan3');
        $this->assertEqual($row['tracker_language'], 'ten3');
        $this->assertEqual($row['connection_language'], 'en3');
        $this->assertEqual($row['tracker_ip_address'], 't127.0.0.3');
        $this->assertEqual($row['connection_ip_address'], '127.0.0.3');
        $this->assertEqual($row['tracker_host_name'], 'thost3');
        $this->assertEqual($row['connection_host_name'], 'host3');
        $this->assertEqual($row['tracker_country'], 'T3');
        $this->assertEqual($row['connection_country'], 'U3');
        $this->assertEqual($row['tracker_https'], 1);
        $this->assertEqual($row['connection_https'], 0);
        $this->assertEqual($row['tracker_domain'], 'tdomain3');
        $this->assertEqual($row['connection_domain'], 'domain3');
        $this->assertEqual($row['tracker_page'], 'tpage3');
        $this->assertEqual($row['connection_page'], 'page3');
        $this->assertEqual($row['tracker_query'], 'tquery3');
        $this->assertEqual($row['connection_query'], 'query3');
        $this->assertEqual($row['tracker_referer'], 'tref3');
        $this->assertEqual($row['connection_referer'], 'ref3');
        $this->assertEqual($row['tracker_search_term'], 'tterm3');
        $this->assertEqual($row['connection_search_term'], 'term3');
        $this->assertEqual($row['tracker_user_agent'], 'tagent3');
        $this->assertEqual($row['connection_user_agent'], 'agent3');
        $this->assertEqual($row['tracker_os'], 'tlinux3');
        $this->assertEqual($row['connection_os'], 'linux3');
        $this->assertEqual($row['tracker_browser'], 'tmozilla3');
        $this->assertEqual($row['connection_browser'], 'mozilla3');
        $this->assertEqual($row['connection_type'], 1);
        $this->assertEqual($row['connection_window'], 4320);
        $this->assertEqual($row['conversion'], 'y');
        $this->assertEqual($row['latest'], 0);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv,
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']} AS diac
            WHERE
                diac.server_raw_tracker_impression_id = 1
                AND diac.server_raw_ip = '127.0.0.1'
                AND diac.data_intermediate_ad_connection_id = diavv.data_intermediate_ad_connection_id";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv
            WHERE
                diavv.tracker_variable_id = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['value'], 1);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv
            WHERE
                diavv.tracker_variable_id = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['value'], 2);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv,
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_connection']} AS diac
            WHERE
                diac.server_raw_tracker_impression_id = 2
                AND diac.server_raw_ip = '127.0.0.2'
                AND diac.data_intermediate_ad_connection_id = diavv.data_intermediate_ad_connection_id";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 4);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv
            WHERE
                diavv.tracker_variable_id = 3";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['value'], 4);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv                
            WHERE
                diavv.tracker_variable_id = 4";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['value'], 3);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv
            WHERE
                diavv.tracker_variable_id = 5";
        $row = $dbh->getRow($query);
        $this->assertNull($row['value']);
        $query = "
            SELECT
                diavv.*
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad_variable_value']} AS diavv                
            WHERE
                diavv.tracker_variable_id = 6";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['value'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 1);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['requests'], 1);
        $this->assertEqual($row['impressions'], 1);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 2);
        $this->assertEqual($row['zone_id'], 2);
        $this->assertEqual($row['requests'], 2);
        $this->assertEqual($row['impressions'], 2);
        $this->assertEqual($row['clicks'], 2);
        $this->assertEqual($row['conversions'], 1);
        $this->assertEqual($row['total_basket_value'], 6);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 3";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 3);
        $this->assertEqual($row['zone_id'], 3);
        $this->assertEqual($row['requests'], 0);
        $this->assertEqual($row['impressions'], 0);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 1);
        $this->assertEqual($row['total_basket_value'], 0);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_intermediate_ad']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_intermediate_ad_connection']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_intermediate_ad_variable_value']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_impression']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_variable_value']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['variables']);
        // Test again without the Tracker module installed
        $conf['modules']['Tracker'] = false;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the (minimum set of) required tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        $dsa->tables->createTable('data_intermediate_ad');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end = new Date('2004-06-06 12:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Re-create dropped tables
        $dsa->tempTables->createTable('tmp_ad_click');
        $dsa->tempTables->createTable('tmp_ad_impression');
        $dsa->tempTables->createTable('tmp_ad_request');
        // Insert the test data
        $result = $dbh->query(SAVE_INTERMEDIATE_AD_CLICKS);
        $result = $dbh->query(SAVE_INTERMEDIATE_AD_IMPRESSIONS);        
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:29:59');
        $dsa->saveIntermediate($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 1);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['impressions'], 1);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 2);
        $this->assertEqual($row['zone_id'], 2);
        $this->assertEqual($row['impressions'], 2);
        $this->assertEqual($row['clicks'], 2);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        $query = "
            SELECT
                * 
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_intermediate_ad']}
            WHERE
                ad_id = 3";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['operation_interval'], 30);
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['creative_id'], 3);
        $this->assertEqual($row['zone_id'], 3);
        $this->assertEqual($row['impressions'], 0);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_intermediate_ad']);
    }

    /**
     * Tests the saveHistory() method.
     */
    function testSaveHistory()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('data_intermediate_ad');
        $dsa->tables->createTable('data_summary_zone_impression_history');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end   = new Date('2004-06-06 12:29:59');
        $dsa->saveHistory($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert the test data
        $result = $dbh->query(SAVE_SUMMARY_INTERMEDIATE_AD);        
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end   = new Date('2004-06-06 18:29:59');
        $dsa->saveHistory($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['operation_interval'], '30');
        $this->assertEqual($row['operation_interval_id'], 36);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:00:00');
        $this->assertEqual($row['interval_end'], '2004-06-06 18:29:59');
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['forecast_impressions'], 1); // Default value in table
        $this->assertEqual($row['actual_impressions'], 4);
        // Insert more test data
        $result = $dbh->query(SAVE_HISTORY_INTERMEDIATE_AD_NEXT);
        // Test
        $start = new Date('2004-06-06 18:30:00');
        $end   = new Date('2004-06-06 18:59:59');
        $dsa->saveHistory($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 2);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}
            WHERE
                operation_interval_id = 37";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['operation_interval'], '30');
        $this->assertEqual($row['operation_interval_id'], 37);
        $this->assertEqual($row['interval_start'], '2004-06-06 18:30:00');
        $this->assertEqual($row['interval_end'], '2004-06-06 18:59:59');
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['forecast_impressions'], 1); // Default value in table
        $this->assertEqual($row['actual_impressions'], 4);
        // Insert some predicted values into the data_summary_zone_impression_history table
        $result = $dbh->query(SAVE_HISTORY_INTERMEDIATE_HISTORY_DUPES);
        // Test
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}
            WHERE
                operation_interval_id = 38";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['operation_interval'], '30');
        $this->assertEqual($row['operation_interval_id'], 38);
        $this->assertEqual($row['interval_start'], '2004-06-06 19:00:00');
        $this->assertEqual($row['interval_end'], '2004-06-06 19:29:59');
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['forecast_impressions'], 1); // Default value in table
        $this->assertEqual($row['actual_impressions'], 0);
        // Insert more test data
        $result = $dbh->query(SAVE_HISTORY_INTERMEDIATE_AD_DUPES);
        // Test
        $start = new Date('2004-06-06 19:00:00');
        $end   = new Date('2004-06-06 19:29:59');
        $dsa->saveHistory($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_zone_impression_history']}
            WHERE
                operation_interval_id = 38";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['operation_interval'], '30');
        $this->assertEqual($row['operation_interval_id'], 38);
        $this->assertEqual($row['interval_start'], '2004-06-06 19:00:00');
        $this->assertEqual($row['interval_end'], '2004-06-06 19:29:59');
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['forecast_impressions'], 1); // Default value in table
        $this->assertEqual($row['actual_impressions'], 4);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_intermediate_ad']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_summary_zone_impression_history']);
    }

    /**
     * Tests the saveSummary() method.
     */
    function testSaveSummary()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();  
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('data_intermediate_ad');
        $dsa->tables->createTable('data_summary_ad_hourly');
        // Test with no data
        $start = new Date('2004-06-06 12:00:00');
        $end   = new Date('2004-06-06 12:29:59');
        $dsa->saveSummary($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_ad_hourly']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 0);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert the test data
        $result = $dbh->query(SAVE_SUMMARY_INTERMEDIATE_AD);        
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end   = new Date('2004-06-06 18:29:59');
        $dsa->saveSummary($start, $end);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_ad_hourly']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_ad_hourly']}
            WHERE
                ad_id = 1
                AND creative_id = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['impressions'], 1);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 1);
        $this->assertEqual($row['total_basket_value'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_ad_hourly']}
            WHERE
                ad_id = 1
                AND creative_id = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['impressions'], 2);
        $this->assertEqual($row['clicks'], 2);
        $this->assertEqual($row['conversions'], 2);
        $this->assertEqual($row['total_basket_value'], 2);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_summary_ad_hourly']}
            WHERE
                ad_id = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['day'], '2004-06-06');
        $this->assertEqual($row['hour'], 18);
        $this->assertEqual($row['creative_id'], 1);
        $this->assertEqual($row['zone_id'], 1);
        $this->assertEqual($row['impressions'], 1);
        $this->assertEqual($row['clicks'], 1);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['total_basket_value'], 0);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_intermediate_ad']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_summary_ad_hourly']);
    }
    
    /**
     * Tests the decrementCampaigns() method.
     */
    function testDecrementCampaigns()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();  
        $conf['maintenance']['operationInterval'] = 60;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('banners');
        $dsa->tables->createTable('campaigns');
        $dsa->tables->createTable('clients');
        $dsa->tables->createTable('data_intermediate_ad');
        // Test with no data
        $summarisedFrom = new Date('2004-06-06 17:00:00');
        $summarisedTo   = new Date('2004-06-06 17:59:59');
        $report = $dsa->decrementCampaigns($summarisedFrom, $summarisedTo);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert the base test data
        $result = $dbh->query(DECREMENT_CAMPAIGNS_CAMPAIGNS);
        $result = $dbh->query(DECREMENT_CAMPAIGNS_CLIENTS);
        $result = $dbh->query(DECREMENT_CAMPAIGNS_BANNERS);
        // Test with no summarised data
        $summarisedFrom = new Date('2004-06-06 17:00:00');
        $summarisedTo   = new Date('2004-06-06 17:59:59');
        $report = $dsa->decrementCampaigns($summarisedFrom, $summarisedTo);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], 10);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 3";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], 10);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 4";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], 10);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 5";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], 10);
        $this->assertEqual($row['clicks'], 10);
        $this->assertEqual($row['conversions'], 10);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 6";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '2004-06-06');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 'f');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 7";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '2004-06-06');
        $this->assertEqual($row['active'], 't');
        // Insert the summary test data - Part 1
        $result = $dbh->query(DECREMENT_CAMPAIGNS_INTERMEDIATE_AD);
        // Test with summarised data
        $summarisedFrom = new Date('2004-06-06 17:00:00');
        $summarisedTo   = new Date('2004-06-06 17:59:59');
        $report = $dsa->decrementCampaigns($summarisedFrom, $summarisedTo);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], 0);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 'f');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 3";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], 5);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 4";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], 0);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 'f');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 5";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], 8);
        $this->assertEqual($row['clicks'], 6);
        $this->assertEqual($row['conversions'], 4);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 't');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 6";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '2004-06-06');
        $this->assertEqual($row['activate'], '0000-00-00');
        $this->assertEqual($row['active'], 'f');
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['campaigns']}
            WHERE
                campaignid = 7";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['views'], -1);
        $this->assertEqual($row['clicks'], -1);
        $this->assertEqual($row['conversions'], -1);
        $this->assertEqual($row['expire'], '0000-00-00');
        $this->assertEqual($row['activate'], '2004-06-06');
        $this->assertEqual($row['active'], 't');
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['banners']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['campaigns']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['clients']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_intermediate_ad']);
    }

    /**
     * Tests the deleteOldData() method.
     */
    function testDeleteOldData()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();  
        $conf['maintenance']['compactStatsGrace'] = 0;
        // Enable the tracker
        $conf['modules']['Tracker'] = true;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('campaigns_trackers');
        $dsa->tables->createTable('data_raw_ad_click');
        $dsa->tables->createTable('data_raw_ad_impression');
        $dsa->tables->createTable('data_raw_ad_request');
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsAdServerMySql.php';
        // Insert the test data
        $result = $dbh->query(DELETE_OLD_DATA_CAMPAIGNS_TRACKERS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_CLICKS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_IMPRESSIONS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_REQUESTS);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        // Disable the tracker
        $conf['modules']['Tracker'] = false;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Drop and re-create the raw tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_click']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_request']);
        $dsa->tables->createTable('data_raw_ad_click');
        $dsa->tables->createTable('data_raw_ad_impression');
        $dsa->tables->createTable('data_raw_ad_request');
        // Re-insert the test data
        $result = $dbh->query(DELETE_OLD_DATA_AD_CLICKS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_IMPRESSIONS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_REQUESTS);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        // Set a compact_stats_grace window
        $conf['maintenance']['compactStatsGrace'] = 3600;
        // Enable the tracker
        $conf['modules']['Tracker'] = true;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Drop and re-create the raw tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_click']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_request']);
        $dsa->tables->createTable('data_raw_ad_click');
        $dsa->tables->createTable('data_raw_ad_impression');
        $dsa->tables->createTable('data_raw_ad_request');
        // Re-insert the test data
        $result = $dbh->query(DELETE_OLD_DATA_AD_CLICKS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_IMPRESSIONS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_REQUESTS);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 5);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 5);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        // Disable the tracker
        $conf['modules']['Tracker'] = false;
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Drop and re-create the raw tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_click']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_request']);
        $dsa->tables->createTable('data_raw_ad_click');
        $dsa->tables->createTable('data_raw_ad_impression');
        $dsa->tables->createTable('data_raw_ad_request');
        // Re-insert the test data
        $result = $dbh->query(DELETE_OLD_DATA_AD_CLICKS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_IMPRESSIONS);
        $result = $dbh->query(DELETE_OLD_DATA_AD_REQUESTS);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_click']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_impression']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_ad_request']}";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 3);
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['campaigns_trackers']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_click']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_impression']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_ad_request']);
    }

    /**
     * Tests the logCompletion() method.
     */
    function testLogCompletion()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $dsa = new MAX_Dal_Statistics_AdServer_MySql();
        // Create the required tables
        $dsa->tables->createTable('log_maintenance_statistics');
        $dsa->tables->createTable('userlog');
        // Test
        $start = new Date('2004-06-06 18:00:00');
        $end = new Date('2004-06-06 18:01:05');
        $report = 'Report Text';
        $dsa->logCompletion($start, $end, 0, $start, $report);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 0";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 0";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['start_run'], '2004-06-06 18:00:00');
        $this->assertEqual($row['end_run'], '2004-06-06 18:01:05');
        $this->assertEqual($row['duration'], 65);
        $this->assertEqual($row['updated_to'], '2004-06-06 18:00:00');
        $start = new Date('2004-06-06 19:00:00');
        $end = new Date('2004-06-06 19:00:05');
        $dsa->logCompletion($start, $end, 1, $start, $report);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 1";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['start_run'], '2004-06-06 19:00:00');
        $this->assertEqual($row['end_run'], '2004-06-06 19:00:05');
        $this->assertEqual($row['duration'], 5);
        $this->assertEqual($row['updated_to'], '2004-06-06 19:00:00');
        $start = new Date('2004-06-06 20:00:00');
        $end = new Date('2004-06-06 21:00:05');
        $dsa->logCompletion($start, $end, 2, $start, $report);
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 1);
        $query = "
            SELECT
                *
            FROM
                {$conf['table']['prefix']}{$conf['table']['log_maintenance_statistics']}
            WHERE
                adserver_run_type = 2";
        $row = $dbh->getRow($query);
        $this->assertEqual($row['start_run'], '2004-06-06 20:00:00');
        $this->assertEqual($row['end_run'], '2004-06-06 21:00:05');
        $this->assertEqual($row['duration'], 3605);
        $this->assertEqual($row['updated_to'], '2004-06-06 20:00:00');
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['log_maintenance_statistics']);
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['userlog']);
    }
    
}

?>
