<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: TestOfDalStatisticsTrackerMySqlSplit.php 2024 2005-03-10 17:21:43Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

require_once MAX_PATH . '/lib/Max.php';
require_once MAX_PATH . '/lib/max/DB.php';
require_once MAX_PATH . '/lib/max/Dal/Statistics/Tracker/MySqlSplit.php';

/**
 * A class for testing the MAX_Dal_Statistics_AdServer_MySqlSplit class.
 */
class Dal_TestOfMaxDalStatisticsTrackerMySqlSplit extends UnitTestCase
{
    
    /**
     * The constructor method.
     */
    function Dal_TestOfMaxDalStatisticsTrackerMySqlSplit()
    {
        $this->UnitTestCase();
    }
    
    /**
     * Tests that the singleton() method only ever returns one class instance.
     */
    function testSingleton()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        $first = new MAX_Dal_Statistics_Tracker_MySqlSplit();
        $second = new MAX_Dal_Statistics_Tracker_MySqlSplit();
        $this->assertIdentical($first, $second);
    }
    
    /**
     * Tests the getMaintenanceStatisticsLastRunInfo() method.
     */
    function testGetMaintenanceStatisticsLastRunInfo()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $conf['table']['split'] = true;
        $conf['maintenance']['operationInterval'] = 60;
        $dsa = new MAX_Dal_Statistics_Tracker_MySqlSplit();
        // Create the required tables
        $now = new Date();
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('log_maintenance_statistics');
        // Test with no data
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertNull($date);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertNull($date);
        // Insert ad impressions
        $now->setHour(18);
        $now->setMinute(22);
        $now->setSecond(10);
        $query = "
            INSERT INTO
                max_data_raw_tracker_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $result = $dbh->query($query);
        $now->setHour(12);
        $now->setMinute(34);
        $now->setSecond(56);
        $query = "
            INSERT INTO
                max_data_raw_tracker_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $result = $dbh->query($query);
        $now->setHour(18);
        $now->setMinute(22);
        $now->setSecond(11);
        $query = "
            INSERT INTO
                max_data_raw_tracker_impression_". $now->format('%Y%m%d') ."
                (
                    date_time
                )
            VALUES
                (
                    '" . $now->format('%Y-%m-%d %H:%M:%S') . "'
                )";
        $result = $dbh->query($query);
        $now->setHour(11);
        $now->setMinute(59);
        $now->setSecond(59);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, $now);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, $now);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsTrackerMySqlSplit.php';
        // Insert an hourly (only) update
        $result = $dbh->query(TOT_SPLIT_LMS_HOUR);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, $now);
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert an operation interval (only) update
        $result = $dbh->query(TOT_SPLIT_LMS_OI);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, new Date('2004-06-06 10:16:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, new Date('2004-06-06 10:15:00'));
        // Insert a dual interval update
        $result = $dbh->query(TOT_SPLIT_LMS_DUAL);
        // Test
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_OI);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        $date = $dsa->getMaintenanceStatisticsLastRunInfo(DAL_STATISTICS_COMMON_UPDATE_HOUR);
        $this->assertEqual($date, new Date('2004-06-07 01:15:00'));
        // Drop the tables
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['log_maintenance_statistics']);
    }

    /**
     * Tests the deleteOldData() method.
     */
    function testDeleteOldData()
    {
        MAX::debug('Running test', PEAR_LOG_INFO);
        // Use a reference to $GLOBALS['_MAX']['CONF'] so that the configuration
        // options can be changed while the test is running
        $conf =& $GLOBALS['_MAX']['CONF'];
        $dbh =& MAX_DB::singleton();
        $conf['table']['split'] = true;
        $conf['maintenance']['compactStatsGrace'] = 0;
        $dsa = new MAX_Dal_Statistics_Tracker_MySqlSplit();
        // Create the required tables
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        // Get the data for the tests
        include_once MAX_PATH . '/lib/max/Dal/data/TestOfStatisticsTrackerMySqlSplit.php';
        // Insert the test data
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_ONE);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_TWO);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_ONE);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_TWO);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_ONE);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_TWO);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $result = $dbh->query($query);
        $this->assertTrue(PEAR::isError($result, DB_ERROR_NOSUCHTABLE));
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $result = $dbh->query($query);
        $this->assertTrue(PEAR::isError($result, DB_ERROR_NOSUCHTABLE));
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $result = $dbh->query($query);
        $this->assertTrue(PEAR::isError($result, DB_ERROR_NOSUCHTABLE));
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        // Drop the tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_variable_value'] . '_' . $now->format('%Y%m%d'));
        // Set a compact_stats_grace window
        $conf['maintenance']['compactStatsGrace'] = 3600;
        // Create the required tables
        $now = new Date('2004-06-05');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        $now = new Date('2004-06-06');
        $dsa->tables->createTable('data_raw_tracker_click', $now);
        $dsa->tables->createTable('data_raw_tracker_impression', $now);
        $dsa->tables->createTable('data_raw_tracker_variable_value', $now);
        // Insert the test data
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_ONE);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_CLICKS_TWO);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_ONE);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_IMPRESSIONS_TWO);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_ONE);
        $result = $dbh->query(TOT_SPLIT_DELETE_OLD_DATA_TRACKER_REQUESTS_TWO);
        // Test
        $summarisedTo = new Date('2004-06-06 17:59:59');
        $dsa->deleteOldData($summarisedTo);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $result = $dbh->query($query);
        $this->assertTrue(PEAR::isError($result, DB_ERROR_NOSUCHTABLE));
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_click']}_" . $now->format('%Y%m%d');
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $result = $dbh->query($query);
        $this->assertTrue(PEAR::isError($result, DB_ERROR_NOSUCHTABLE));
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_impression']}_" . $now->format('%Y%m%d');
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        $now = new Date('2004-06-05');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $result = $dbh->query($query);
        $this->assertTrue(PEAR::isError($result, DB_ERROR_NOSUCHTABLE));
        $now = new Date('2004-06-06');
        $query = "
            SELECT
                COUNT(*) AS number
            FROM
                {$conf['table']['prefix']}{$conf['table']['data_raw_tracker_variable_value']}_" . $now->format('%Y%m%d');
        $row = $dbh->getRow($query);
        $this->assertEqual($row['number'], 6);
        // Drop the tables
        $now = new Date('2004-06-06');
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_click'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_impression'] . '_' . $now->format('%Y%m%d'));
        $dsa->tables->dropTable($conf['table']['prefix'].$conf['table']['data_raw_tracker_variable_value'] . '_' . $now->format('%Y%m%d'));
    }
    
}

?>
