<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: all_tests.php 2024 2005-03-10 17:21:43Z andrew $
*/

/**
 * @package    MaxDal
 * @subpackage TestSuite
 * @author     Andrew Hill <andrew@awarez.net>
 */

/**
 * A script for running the Maintenance Data Access Layer tests. Designed to
 * be included in a main, project-wide all_tests.php file, or to be run by
 * itself.
 */

// Require the initialisation file
if (!defined('MAX_PATH')) {
    include_once '../../../../init.php';
    // Require that the configuration use a max_ table prefix
    $conf =& $GLOBALS['_MAX']['CONF'];
    $conf['table']['prefix'] = 'max_';
}

// Include the simpletest classes, if required
require_once MAX_PATH . '/lib/simpletest/unit_tester.php';
require_once MAX_PATH . '/lib/simpletest/reporter.php';

global $testStart, $testEnd;
if (!isset($testStart)) {
    // Output the HTML header
    include_once MAX_PATH . '/tests/header.html';
    // Record the test start time
    $testStart = time();
    $runTime = true;
}

// Run the tests on the Data Access Layer that do NOT need a database
$test = &new GroupTest('Data Access Layer: Base Tests');
$test->addTestFile(MAX_PATH . '/lib/max/Dal/tests/TestOfDal.php');
$test->run(new HtmlReporter());

// Don't use a PEAR_Error handler for Maintenance Statistics tests
PEAR::pushErrorHandling(null);

// Run the tests on the Data Access Layer (Maintenance Statistics) that do NOT need a database
$test = &new GroupTest('Data Access Layer (Maintenance Statistics): Base Tests');
$test->addTestFile(MAX_PATH . '/lib/max/Dal/tests/TestOfDalStatistics.php');
$test->addTestFile(MAX_PATH . '/lib/max/Dal/tests/TestOfDalStatisticsCommon.php');
$test->run(new HtmlReporter());

// Resore the PEAR_Error handler
PEAR::popErrorHandling();

// Configure a connection to the test database
require_once MAX_PATH . '/lib/max/DB.php';
$dbh =& MAX_DB::singleton();
$query = "DROP DATABASE IF EXISTS max_simpletest";
$result = $dbh->query($query);
$query = "CREATE DATABASE max_simpletest";
$result = $dbh->query($query);
$conf =& $GLOBALS['_MAX']['CONF'];
$backup = $conf['database']['name'];
$conf['database']['name'] = 'max_simpletest';

// Don't use a PEAR_Error handler for Maintenance Statistics tests
PEAR::pushErrorHandling(null);

// Run the tests on the Data Access Layer (Maintenance Statistics) that DO need a database
$test = &new GroupTest('Data Access Layer (Maintenance Statistics): Data Tests');
$test->addTestFile(MAX_PATH . '/lib/max/Dal/tests/TestOfDalStatisticsAdServerMySql.php');
$test->addTestFile(MAX_PATH . '/lib/max/Dal/tests/TestOfDalStatisticsAdServerMySqlSplit.php');
$test->addTestFile(MAX_PATH . '/lib/max/Dal/tests/TestOfDalStatisticsTrackerMySql.php');
$test->addTestFile(MAX_PATH . '/lib/max/Dal/tests/TestOfDalStatisticsTrackerMySqlSplit.php');
$test->run(new HtmlReporter());

// Resore the PEAR_Error handler
PEAR::popErrorHandling();

// Drop the test database
$conf['database']['name'] = $backup;
$dbh =& MAX_DB::singleton();
$query = "DROP DATABASE max_simpletest";
$result = $dbh->query($query);

if ($runTime) {
    // Calculate and display the test run time
    $testEnd = time();
    $time = $testEnd - $testStart;
    echo '<p>Tests took ' . $time . ' seconds</p>';
    // Output the HTML footer
    include_once MAX_PATH . '/tests/footer.html';
}

?>
