<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| Copyright (c) 2000-2003 the phpAdsNew developers                          |
| For contact details, see: http://www.phpadsnew.com/                       |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: publisheradvertising.plugin.php 2024 2005-03-10 17:21:43Z andrew $
*/

include_once('lib.php');

// Public name of the plugin info function
$plugin_info_function		= "Plugin_PublisherAdvertisingSummaryInfo";


// Public info function
function Plugin_PublisherAdvertisingSummaryInfo()
{
	$plugininfo = array (
		"plugin-name"			=> $GLOBALS['strPublisherAdvertisingSummaryReport'],
		"plugin-description"	=> $GLOBALS['strPublisherAdvertisingSummaryDescription'],
		'plugin-category'     => 'publisher',
		"plugin-author"			=> "Michal Pawlowski",
		"plugin-export"			=> "csv",
		"plugin-authorize"		=> phpAds_Admin+phpAds_Agency+phpAds_Affiliate,
		"plugin-execute"		=> "Plugin_PublisherAdvertisingSummaryExecute",
		"plugin-import"			=> array (
			"campaignid"			=> array (
				"title"					=> $GLOBALS['strAffiliate'],
				"type"					=> "affiliateid-dropdown" ),
			"startdate"				=> array (
                "title"					=> "Start Date",
                "type"					=> "edit",
                "size"					=> 10,
                "default"				=> date("Y/m/d",mktime (0,0,0,date("m")-1,1,  date("Y")))
            ),
            "enddate"				=> array (
                "title"					=> "End Date",
                "type"					=> "edit",
                "size"					=> 10,
                "default"				=> date("Y/m/d",mktime (0,0,0,date("m"),1,  date("Y")))
            ),
		 )
	);
	
	return ($plugininfo);
}

/*-------------------------------------------------------*/
/* Private plugin function                               */
/*-------------------------------------------------------*/
function Plugin_PublisherAdvertisingSummaryExecute($affiliateid, $startdate, $enddate)
{
    
    require_once 'Spreadsheet/Excel/Writer.php';
        
	global $date_format;
	global $strAffiliate;
	
	$conf = & $GLOBALS['_MAX']['CONF'];
	
	$reportName = $GLOBALS['strPublisherAdvertisingSummaryReport'];
	
	$startDate = date(str_replace('%','',$date_format), strtotime($startdate));
	$endDate   = date(str_replace('%','',$date_format), strtotime($enddate));
	$dbStart = date('Y-m-d', strtotime($startdate));
	$dbEnd = date('Y-m-d', strtotime($enddate));
	// creating report object
    $workbook = new Spreadsheet_Excel_Writer();
    
    $worksheet = generateXLSHeader($workbook, $reportName, $startDate, $endDate,
                                   $affiliateid, $GLOBALS['strPublisherAdvertisingSummaryDescription']);
    // where to start printing structural data
    $rowStart = 8;
    $columnStart = 0;
    
    // formatting
    $formatInteger = &$workbook->addFormat();
    $formatInteger->setNumFormat($GLOBALS['excell_integer_formatting']);
    
    $formatDecimal = &$workbook->addFormat();
    $formatDecimal->setNumFormat($GLOBALS['excell_decimal_formatting']);
    
    $columnHeader = &$workbook->addFormat();
    $columnHeader->setAlign('center');
    $columnHeader->setBold();
    
    $query = "SELECT
                   c.priority
                  ,coalesce(sum(ds.requests),0)        as requests
                  ,coalesce(sum(ds.impressions),0)     as impressions
                  ,coalesce(sum(ds.clicks),0)          as clicks
                  ,coalesce(sum(ds.conversions),0)     as conversions
              FROM ".$conf['table']['prefix'].$conf['table']['zones']." z
                  ,".$conf['table']['prefix'].$conf['table']['data_summary_ad_hourly']." ds
                  ,".$conf['table']['prefix'].$conf['table']['banners']." b
                  ,".$conf['table']['prefix'].$conf['table']['campaigns']." c
             WHERE z.zoneid = ds.zone_id
               AND ds.ad_id = b.bannerid
               AND b.campaignid = c.campaignid
               AND z.affiliateid = ".$affiliateid."
               AND ds.day >= '$dbStart'
               AND ds.day <= '$dbEnd'
             GROUP BY c.priority
             ORDER BY c.priority ASC";
    
	$res = phpAds_dbQuery($query) or phpAds_sqlDie();
	
	// getting the db result to the temporary table - results needs to be prepared first
	while ($row = phpAds_dbFetchArray($res)) {
	    $data[] = $row;
	}
	
    $numrows = (is_array($data)) ? count($data): 0;
    
    // preparing result data
	$row = Plugin_strAdvertisingReportPrepareData($data);
	//var_dump($row);
	$priorityNames = array('l' => $GLOBALS['strPriorityLow']
	                      ,'m' => $GLOBALS['strPriorityMedium']
	                      ,'h' => $GLOBALS['strPriorityHigh']
	                      ,'t' => "All Campaigns");
	$previousPriority = '';
	$previousStart = $currentRow = $rowStart;
	
    $worksheet->write($currentRow,$columnStart + 1,$GLOBALS['strValue']   , $columnHeader);
    
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strRequests']);
    $worksheet->writeNumber($currentRow, $columnStart + 1, $row['requests'],$formatInteger);
    $currentRow++;
    $currentRow++;
    $worksheet->write($currentRow, $columnStart, $GLOBALS['strViews'], $columnHeader);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strPriorityHigh']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            $row['views']['h'],$formatInteger);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strPriorityMedium']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            $row['views']['m'],$formatInteger);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strPriorityLow']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            $row['views']['l'],$formatInteger);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strTotal']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            $row['views']['total'],$formatInteger);
    $currentRow++;
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strClicks'], $columnHeader);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            $row['clicks']['total'],$formatInteger);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strCTR']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            ($row['clicks']['total'] / $row['views']['total']) * 100,$formatDecimal);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strCTRShortHigh']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            ($row['clicks']['h'] / $row['views']['h']) * 100,$formatDecimal);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strCTRShortMedium']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            ($row['clicks']['m'] / $row['views']['m']) * 100,$formatDecimal);
    $currentRow++;
	$worksheet->write($currentRow, $columnStart, $GLOBALS['strCTRShortLow']);
    $worksheet->writeNumber($currentRow, $columnStart + 1,
                            ($row['clicks']['l'] / $row['views']['l']) * 100,$formatDecimal);
    $currentRow++;
	
    $workbook->close();
}

/*----------------------------------------*/
/* Function preparing data for display    */
/*----------------------------------------*/
function Plugin_strAdvertisingReportPrepareData(& $data)
{
    $retArray = array();

    foreach ($data as $row) {
        $retArray['requests'] += $row['requests'];
        $retArray['views'][$row['priority']] = $row['impressions'];
        $retArray['views']['total'] += $row['impressions'];
        $retArray['clicks'][$row['priority']] = $row['clicks'];
        $retArray['clicks']['total'] += $row['clicks'];
    }
    
    return $retArray;
}

?>