<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| Copyright (c) 2000-2003 the phpAdsNew developers                          |
| For contact details, see: http://www.phpadsnew.com/                       |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: settings-invocation.php 2024 2005-03-10 17:21:43Z andrew $
*/

// Require the initialisation file
require_once '../../init.php';

// Required files
require_once MAX_PATH . '/lib/max/Admin/Redirect.php';
require_once MAX_PATH . '/www/admin/lib-settings.inc.php';

// Security check
phpAds_checkAccess(phpAds_Admin + phpAds_Agency);

$errormessage = array();
if (isset($_POST['submit']) && $_POST['submit'] == 'true') {
    // Register input variables
    phpAds_registerGlobal('allow_invocation_plain', 'allow_invocation_plain_nocookies',
                          'allow_invocation_js', 'allow_invocation_frame',
                          'allow_invocation_xmlrpc', 'allow_invocation_local',
                          'allow_invocation_interstitial', 'allow_invocation_popup');
    // Set up the preferences object
    $preferences = new MAX_Admin_Preferences();
    $preferences->setPrefChange('allow_invocation_plain',           isset($allow_invocation_plain));
    $preferences->setPrefChange('allow_invocation_plain_nocookies', isset($allow_invocation_plain_nocookies));
    $preferences->setPrefChange('allow_invocation_js',              isset($allow_invocation_js));
    $preferences->setPrefChange('allow_invocation_frame',           isset($allow_invocation_frame));
    $preferences->setPrefChange('allow_invocation_xmlrpc',          isset($allow_invocation_xmlrpc));
    $preferences->setPrefChange('allow_invocation_local',           isset($allow_invocation_local));
    $preferences->setPrefChange('allow_invocation_interstitial',    isset($allow_invocation_interstitial));
    $preferences->setPrefChange('allow_invocation_popup',           isset($allow_invocation_popup));    
    if (!$preferences->writePrefChange()) {
        // Unable to update the preferences
        $errormessage[0][] = $strUnableToWritePrefs;
    } else {
        if (phpAds_isUser(phpAds_Admin)) {
            MAX_Admin_Redirect::redirect('settings-stats.php');
        } else {
            MAX_Admin_Redirect::redirect('settings-interface.php');
        }
    }
}

phpAds_PrepareHelp();
phpAds_PageHeader("5.1");
if (phpAds_isUser(phpAds_Admin)) {
    phpAds_ShowSections(array("5.1", "5.3", "5.4", "5.2","5.5"));
} elseif (phpAds_isUser(phpAds_Agency)) {
    phpAds_ShowSections(array("5.1"));
}
phpAds_SettingsSelection("invocation");

$settings = array (
    array (
        'text'  => $strAllowedInvocationTypes,
        'items' => array (
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_plain',
                'text' => $strAllowRemoteInvocation
            ),
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_plain_nocookies',
                'text' => $strAllowRemoteInvocationNoCookies
            ),
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_js',
                'text' => $strAllowRemoteJavascript
            ),
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_frame',
                'text' => $strAllowRemoteFrames
            ),
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_xmlrpc',
                'text' => $strAllowRemoteXMLRPC
            ),
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_local',
                'text' => $strAllowLocalmode
            ),
            array (
                'type' => 'break'
            ),
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_interstitial',
                'text' => $strAllowInterstitial
            ),
            array (
                'type' => 'break'
            ),
            array (
                'type' => 'checkbox',
                'name' => 'allow_invocation_popup',
                'text' => $strAllowPopups
            )
        )
    )
);

phpAds_ShowSettings($settings, $errormessage);
phpAds_PageFooter();

?>
