<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| Copyright (c) 2000-2003 the phpAdsNew developers                          |
| For contact details, see: http://www.phpadsnew.com/                       |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: adview.php 2024 2005-03-10 17:21:43Z andrew $
*/

// Require the initialisation file
require_once '../../init-delivery.php';

// Required files
if ($conf['debug']['benchmark'] == 'true') {
    include_once 'Timer.php';
    $timer = new Benchmark_Timer();
    $timer->start();
}

require_once MAX_PATH . '/lib/max/other/lib-io.inc.php';
require_once MAX_PATH . '/lib/max/other/lib-db.inc.php';
require_once MAX_PATH . '/lib/max/other/lib-view-main.inc.php';
require_once MAX_PATH . '/lib/max/other/lib-remotehost.inc.php';
require_once MAX_PATH . '/lib/max/other/lib-log.inc.php';
if ($conf['delivery']['acls']) {
    require_once MAX_PATH . '/lib/max/other/lib-limitations.inc.php';
}
require_once MAX_PATH . '/lib/max/other/lib-cache.inc.php';

/*-------------------------------------------------------*/
/* Register input variables                              */
/*-------------------------------------------------------*/

phpAds_registerGlobal (
	'source'
	,'n'
	,'what'
	,'referer'
	,'zoneid'
	,'campaignid'
	,'bannerid'
	,'loc'
);

/*-------------------------------------------------------*/
/* Main code                                             */
/*-------------------------------------------------------*/

if (!isset($n)) {
    $n = 'default';
}
if (!isset($source)) {
    $source = '';
}
if (!isset($what)) {
    if ($zoneid) {
        $what = 'zone:'.$zoneid;
    }
    if ($campaignid) {
        $what = 'campaignid:'.$campaignid;
    }
    if ($bannerid) {
        $what = 'bannerid:'.$bannerid;
    }
    if (!isset($what)) {
        $what = '';
    }
}
if ((!isset($zoneid) or $zoneid == 0)) {
    if (substr($what,0,5) == 'zone:') {
        $zoneid =  intval(substr($what,5));
    } else {
        $zoneid = 0;
    }
}

$source = phpAds_deriveSource($source);

// Remove referer, to be sure it doesn't cause problems with limitations
if (isset($_SERVER['HTTP_REFERER'])) {
    unset($_SERVER['HTTP_REFERER']);
}
if (isset($HTTP_REFERER)) {
    unset($HTTP_REFERER);
}

$richMedia = false;     // This is an image tag - we only need the filename (or URL?) of the image...
$target = '';           // Target cannot be dynamically set in basic tags.
$context = '';          // I am not sure what context does...
$ct0 = '';              // Click tracking should be done using external tags rather than this way...
$withText = 0;          // Cannot write text using a simple tag...
$row = view_raw($what, $target, $source, $withText, $context, $richMedia, $ct0, $GLOBALS['loc'], $GLOBALS['referer']);

if (!empty($row['html'])) {
    // Send bannerid headers
    $cookie = array();
    $cookie['bannerid'] = $row['bannerid'];
    // Send zoneid headers
    if ($zoneid != 0) {
    	$cookie['zoneid'] = $zoneid;
    }
    // Send source headers
    if (!empty($source)) {
    	$cookie['source'] = $source;
    }
    // Added code to update the destination URL stored in the cookie to hold the correct random value (Bug # 88)
    global $cookie_random;
    $cookie['maxdest'] = str_replace('{random}', $cookie_random, $row['url']);
    // The call to view_raw() above will have tried to log the impression via a beacon,
    // but this type of ad doesn't work with beacons, so the impression must
    // be logged here
    if ($conf['logging']['adImpressions']) {
        $userid = phpAds_getUniqueUserID();
        phpAds_setCookie("phpAds_id", $userid, time()+365*24*60*60);
        logAdImpression($userid, $row['bannerid'], null, $zoneid);
    }
    // Redirect to the banner
    phpAds_setCookie("phpAds_banner[$n]", serialize($cookie), 0);
    phpAds_flushCookie();
	header("Location: {$row['html']}");
} else {
	phpAds_setCookie("phpAds_banner[$n]", 'DEFAULT', 0);
	phpAds_flushCookie();
	// Show 1x1 Gif, to ensure not broken image icon is shown.
	header('Content-type: image/gif');
	echo base64_decode('R0lGODlhAQABAIAAAP///wAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw==');
}

if ($conf['debug']['benchmark'] == 'true') {
    $timer->stop();
    logBenchmark(basename($_SERVER['SCRIPT_FILENAME']), $_SERVER['QUERY_STRING'], $timer->timeElapsed());
}

?>
