<?php

/*
+---------------------------------------------------------------------------+
| Max Media Manager v0.3                                                    |
| =================                                                         |
|                                                                           |
| Copyright (c) 2003-2005 Awarez Ltd.                                       |
| For contact details, see: http://www.awarez.net/                          |
|                                                                           |
| Copyright (c) 2000-2003 the phpAdsNew developers                          |
| For contact details, see: http://www.phpadsnew.com/                       |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: lg.php 2024 2005-03-10 17:21:43Z andrew $
*/

/**
 * @package    MaxDelivery
 * @author     Scott Switzer <scott@switzer.org>
 */

// Require the initialisation file
require_once '../../init-delivery.php';

// Required files
require_once MAX_PATH . '/lib/max/Delivery.php';
require_once MAX_PATH . '/lib/max/other/lib-log.inc.php';

// Remove any special characters
removeSpecialChars($_REQUEST);

// Get the variables
$viewerId   = isset($_COOKIE[$conf['var']['viewerId']]) ? $_COOKIE[$conf['var']['viewerId']] : '';
$adId       = isset($_REQUEST[$conf['var']['adId']]) ? intval($_REQUEST[$conf['var']['adId']]) : 0;
$zoneId     = isset($_REQUEST[$conf['var']['zoneId']]) ? intval($_REQUEST[$conf['var']['zoneId']]) : 0;
$creativeId = isset($_REQUEST[$conf['var']['creativeId']]) ? intval($_REQUEST[$conf['var']['creativeId']]) : 0;

if (($adId > 0) && ($conf['logging']['adImpressions'])) {
    // Log the impression in the database
    logAdImpression($viewerId, $adId, $creativeId, $zoneId);
    // If this ad is capped, increment the number of times that it has been viewed.
    updateAdImpressionCookies($conf, $adId);
}

// Display a 1x1 pixel gif
displayImageBeacon();

// Stop benchmarking
stopBenchmark();

/**
 * Check to see if this particular ad impression needs cookies set, and set them
 *
 * 1.  Check to see if the ad is capped, and if so, increment the value by 1
 * 2.  Check to see if the ad is blocked, and if so, update the date/time that it was viewed.
 * 3.  Repeat for session based capping and blocking
 *
 * @param array $conf The configuration array
 * @param integer $adId The ID of the ad that was viewed
 */
function updateAdImpressionCookies($conf, $adId)
{
    $time = time();
    _setAdImpressionCookie($conf, 'capAd', $adId, $time, true, 'cap');
    _setAdImpressionCookie($conf, 'sessionCapAd', $adId, $time, false, 'cap');
    _setAdImpressionCookie($conf, 'blockAd', $adId, $time, true, 'block');
    _setAdImpressionCookie($conf, 'sessionBlockAd', $adId, $time, false, 'block');
}

/**
 * Check to see if a value is present in the cookie or request for a given parameter.  If it is, then update it.
 *
 * @param array $conf The configuration array
 * @param string $varName The name of the variable to check
 * @param integer $adId The ID of the ad that was viewed
 * @param integer $time The server time in UNIX format
 * @param boolean $permanent True if there should be a permanent cookie, false if there should be a session cookie
 * @param string $type If it is a capping cookie, then the value will be 'cap'.  If it is a time limitation cookie, then the value will be 'block'
 */
function _setAdImpressionCookie($conf, $varName, $adId, $time, $permanent = true, $type = 'cap')
{
    // Get the name of the cookie or request variable
    $name = $conf['var'][$varName];
    $cookieName = $name . '[' . $adId . ']';
    // Get the cookie expiration date
    $expire = $permanent ? $time + $conf['cookie']['permCookieSeconds'] : 0;
    // Get the value of the variable from either the cookie or request
    if (isset($_COOKIE[$name][$adId])) {
        $value = $_COOKIE[$name][$adId];
    } elseif (isset($_REQUEST[$name])) {
        $value = $_REQUEST[$name];
    } else {
        $value = false;
    }
    if ($value !== false) {
        $value = $type == 'cap' ? intval($value) + 1 : $time;
        setcookie($cookieName, $value, $expire);
    }
}

/**
 * Display a 1x1 pixel gif.  Include the appropriate image headers
 */
function displayImageBeacon()
{
    header('Content-Type: image/gif');
    header('Content-Length: 43');
    // 1 x 1 gif
    echo base64_decode('R0lGODlhAQABAIAAAP///wAAACH5BAAAAAAALAAAAAABAAEAAAICRAEAOw==');
}

?>
